SmileIDBiometricKYC class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SmileIDBiometricKYC
Constructors
-
SmileIDBiometricKYC({Key? key, required String? country, String? idType, String? idNumber, String? firstName, String? middleName, String? lastName, String? dob, String? bankCode, bool? entered, String? userId, String? jobId, String? consentGrantedDate, bool? personalDetailsConsentGranted, bool? contactInformationConsentGranted, bool? documentInformationConsentGranted, bool allowNewEnroll = false, bool allowAgentMode = false, bool forceAgentMode = false, bool showAttribution = true, bool showInstructions = true, SmileSensitivity smileSensitivity = SmileSensitivity.normal, bool useStrictMode = false, bool skipApiSubmission = false, Map<
String, String> ? extraPartnerParams, required dynamic onSuccess(String resultJson), required dynamic onError(String errorMessage)}) -
factory
Properties
-
creationParams
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onError → dynamic Function(String)
-
final
- onSuccess → dynamic Function(String)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited